"""Endpoint catalog starter for multi-version wrappers.

This is intentionally small in v0.1 and meant to be expanded/generated.
"""

ENDPOINT_CATALOG: dict[str, dict[str, dict[str, str]]] = {
    "workspace": {
        "2.0": {
            "clusters_create": "/api/2.0/clusters/create",
            "clusters_delete": "/api/2.0/clusters/delete",
            "clusters_edit": "/api/2.0/clusters/edit",
            "clusters_events": "/api/2.0/clusters/events",
            "clusters_get": "/api/2.0/clusters/get",
            "clusters_list": "/api/2.0/clusters/list",
            "clusters_permanent_delete": "/api/2.0/clusters/permanent-delete",
            "clusters_restart": "/api/2.0/clusters/restart",
            "clusters_start": "/api/2.0/clusters/start",
            "repos_update": "/api/2.0/repos/{repo_id}",
            "repos_list": "/api/2.0/repos",
            "repos_get": "/api/2.0/repos/{repo_id}",
            "repos_create": "/api/2.0/repos",
            "repos_delete": "/api/2.0/repos/{repo_id}",
            "git_credentials_list": "/api/2.0/git-credentials",
            "git_credentials_create": "/api/2.0/git-credentials",
            "git_credentials_get": "/api/2.0/git-credentials/{credential_id}",
            "git_credentials_update": "/api/2.0/git-credentials/{credential_id}",
            "git_credentials_delete": "/api/2.0/git-credentials/{credential_id}",
            "secrets_put": "/api/2.0/secrets/put",
            "secrets_delete": "/api/2.0/secrets/delete",
            "secrets_get": "/api/2.0/secrets/get",
            "secrets_list": "/api/2.0/secrets/list",
            "secret_acls_list": "/api/2.0/secrets/acls/list",
            "secret_acls_get": "/api/2.0/secrets/acls/get",
            "secret_acls_put": "/api/2.0/secrets/acls/put",
            "secret_acls_delete": "/api/2.0/secrets/acls/delete",
            "secret_scopes_create": "/api/2.0/secrets/scopes/create",
            "secret_scopes_list": "/api/2.0/secrets/scopes/list",
            "secret_scopes_delete": "/api/2.0/secrets/scopes/delete",
            "token_create": "/api/2.0/token/create",
            "token_delete": "/api/2.0/token/delete",
            "token_list": "/api/2.0/token/list",
            "token_revoke": "/api/2.0/token/delete",
            "sql_warehouses_list": "/api/2.0/sql/warehouses",
            "sql_warehouses_get": "/api/2.0/sql/warehouses/{warehouse_id}",
            "sql_warehouses_create": "/api/2.0/sql/warehouses",
            "sql_warehouses_edit": "/api/2.0/sql/warehouses/{warehouse_id}/edit",
            "sql_warehouses_delete": "/api/2.0/sql/warehouses/{warehouse_id}",
            "sql_warehouses_start": "/api/2.0/sql/warehouses/{warehouse_id}/start",
            "sql_warehouses_stop": "/api/2.0/sql/warehouses/{warehouse_id}/stop",
            "permissions_warehouses_get": "/api/2.0/permissions/warehouses/{warehouse_id}",
            "permissions_warehouses_set": "/api/2.0/permissions/warehouses/{warehouse_id}",
            "permissions_warehouses_update": "/api/2.0/permissions/warehouses/{warehouse_id}",
            "permissions_warehouses_permission_levels": "/api/2.0/permissions/warehouses/{warehouse_id}/permissionLevels",
            "sql_statements_execute": "/api/2.0/sql/statements",
            "sql_statements_get": "/api/2.0/sql/statements/{statement_id}",
            "sql_statements_cancel": "/api/2.0/sql/statements/{statement_id}/cancel",
            "sql_statements_result_chunk": "/api/2.0/sql/statements/{statement_id}/result/chunks/{chunk_index}",
            "mlflow_experiments_create": "/api/2.0/mlflow/experiments/create",
            "mlflow_experiments_delete": "/api/2.0/mlflow/experiments/delete",
            "mlflow_experiments_get": "/api/2.0/mlflow/experiments/get",
            "mlflow_experiments_get_by_name": "/api/2.0/mlflow/experiments/get-by-name",
            "mlflow_experiments_list": "/api/2.0/mlflow/experiments/list",
            "mlflow_experiments_search": "/api/2.0/mlflow/experiments/search",
            "mlflow_experiments_restore": "/api/2.0/mlflow/experiments/restore",
            "mlflow_experiments_update": "/api/2.0/mlflow/experiments/update",
            "mlflow_experiments_set_tag": "/api/2.0/mlflow/experiments/set-experiment-tag",
            "mlflow_runs_create": "/api/2.0/mlflow/runs/create",
            "mlflow_runs_delete": "/api/2.0/mlflow/runs/delete",
            "mlflow_runs_restore": "/api/2.0/mlflow/runs/restore",
            "mlflow_runs_get": "/api/2.0/mlflow/runs/get",
            "mlflow_runs_search": "/api/2.0/mlflow/runs/search",
            "mlflow_runs_log_metric": "/api/2.0/mlflow/runs/log-metric",
            "mlflow_runs_log_parameter": "/api/2.0/mlflow/runs/log-parameter",
            "mlflow_runs_set_tag": "/api/2.0/mlflow/runs/set-tag",
            "mlflow_registered_models_create": "/api/2.0/mlflow/registered-models/create",
            "mlflow_registered_models_delete": "/api/2.0/mlflow/registered-models/delete",
            "mlflow_registered_models_get": "/api/2.0/mlflow/registered-models/get",
            "mlflow_registered_models_update": "/api/2.0/mlflow/registered-models/update",
            "mlflow_registered_models_rename": "/api/2.0/mlflow/registered-models/rename",
            "mlflow_registered_models_search": "/api/2.0/mlflow/registered-models/search",
            "mlflow_registered_models_set_tag": "/api/2.0/mlflow/registered-models/set-tag",
            "mlflow_registered_models_delete_tag": "/api/2.0/mlflow/registered-models/delete-tag",
            "mlflow_registered_models_get_latest_versions": "/api/2.0/mlflow/registered-models/get-latest-versions",
            "mlflow_model_versions_create": "/api/2.0/mlflow/model-versions/create",
            "mlflow_model_versions_delete": "/api/2.0/mlflow/model-versions/delete",
            "mlflow_model_versions_get": "/api/2.0/mlflow/model-versions/get",
            "mlflow_model_versions_search": "/api/2.0/mlflow/model-versions/search",
            "mlflow_model_versions_update": "/api/2.0/mlflow/model-versions/update",
            "mlflow_model_versions_set_tag": "/api/2.0/mlflow/model-versions/set-tag",
            "mlflow_model_versions_delete_tag": "/api/2.0/mlflow/model-versions/delete-tag",
            "mlflow_model_versions_transition_stage": "/api/2.0/mlflow/model-versions/transition-stage",
            "permissions_registered_models_get": "/api/2.0/permissions/registered-models/{model_name}",
            "permissions_registered_models_set": "/api/2.0/permissions/registered-models/{model_name}",
            "permissions_registered_models_update": "/api/2.0/permissions/registered-models/{model_name}",
            "permissions_registered_models_permission_levels": "/api/2.0/permissions/registered-models/{model_name}/permissionLevels",
            "mlflow_registry_webhooks_create": "/api/2.0/mlflow/registry-webhooks/create",
            "mlflow_registry_webhooks_list": "/api/2.0/mlflow/registry-webhooks/list",
            "mlflow_registry_webhooks_update": "/api/2.0/mlflow/registry-webhooks/update",
            "mlflow_registry_webhooks_delete": "/api/2.0/mlflow/registry-webhooks/delete",
            "mlflow_registry_webhooks_test": "/api/2.0/mlflow/registry-webhooks/test",
            "mlflow_comments_create": "/api/2.0/mlflow/comments/create",
            "mlflow_comments_update": "/api/2.0/mlflow/comments/update",
            "mlflow_comments_delete": "/api/2.0/mlflow/comments/delete",
            "mlflow_transition_requests_create": "/api/2.0/mlflow/transition-requests/create",
            "mlflow_transition_requests_list": "/api/2.0/mlflow/transition-requests/list",
            "mlflow_transition_requests_approve": "/api/2.0/mlflow/transition-requests/approve",
            "mlflow_transition_requests_reject": "/api/2.0/mlflow/transition-requests/reject",
            "mlflow_transition_requests_delete": "/api/2.0/mlflow/transition-requests/delete",
            "sql_alerts_list": "/api/2.0/sql/alerts",
            "sql_alerts_create": "/api/2.0/sql/alerts",
            "sql_alerts_get": "/api/2.0/sql/alerts/{alert_id}",
            "sql_alerts_update": "/api/2.0/sql/alerts/{alert_id}",
            "sql_alerts_delete": "/api/2.0/sql/alerts/{alert_id}",
            "sql_queries_list": "/api/2.0/sql/queries",
            "sql_queries_create": "/api/2.0/sql/queries",
            "sql_queries_get": "/api/2.0/sql/queries/{query_id}",
            "sql_queries_update": "/api/2.0/sql/queries/{query_id}",
            "sql_queries_delete": "/api/2.0/sql/queries/{query_id}",
            "dashboards_list": "/api/2.0/lakeview/dashboards",
            "dashboards_create": "/api/2.0/lakeview/dashboards",
            "dashboards_get": "/api/2.0/lakeview/dashboards/{dashboard_id}",
            "dashboards_update": "/api/2.0/lakeview/dashboards/{dashboard_id}",
            "dashboards_trash": "/api/2.0/lakeview/dashboards/{dashboard_id}/trash",
            "dashboards_publish": "/api/2.0/lakeview/dashboards/{dashboard_id}/published",
            "dashboards_unpublish": "/api/2.0/lakeview/dashboards/{dashboard_id}/published",
            "apps_list": "/api/2.0/apps",
            "apps_create": "/api/2.0/apps",
            "apps_get": "/api/2.0/apps/{app_name}",
            "apps_update": "/api/2.0/apps/{app_name}",
            "apps_delete": "/api/2.0/apps/{app_name}",
            "apps_start": "/api/2.0/apps/{app_name}/start",
            "apps_stop": "/api/2.0/apps/{app_name}/stop",
            "apps_permissions_get": "/api/2.0/permissions/apps/{app_name}",
            "apps_permissions_set": "/api/2.0/permissions/apps/{app_name}",
            "apps_permissions_patch": "/api/2.0/permissions/apps/{app_name}",
            "apps_permissions_levels": "/api/2.0/permissions/apps/{app_name}/permissionLevels",
            "token_management_list_all_tokens": "/api/2.0/token-management/tokens",
            "token_management_get_token_info": "/api/2.0/token-management/tokens/{token_id}",
            "command_execution_context_create": "/api/2.0/command-execution/contexts/create",
            "command_execution_context_delete": "/api/2.0/command-execution/contexts/destroy",
            "command_execution_command_run": "/api/2.0/command-execution/commands/execute",
            "command_execution_command_status": "/api/2.0/command-execution/commands/status",
            "command_execution_command_cancel": "/api/2.0/command-execution/commands/cancel",
            "clean_rooms_list": "/api/2.0/clean-rooms",
            "clean_rooms_create": "/api/2.0/clean-rooms",
            "clean_rooms_get": "/api/2.0/clean-rooms/{clean_room_name}",
            "clean_rooms_update": "/api/2.0/clean-rooms/{clean_room_name}",
            "clean_rooms_delete": "/api/2.0/clean-rooms/{clean_room_name}",
            "clean_rooms_assets_list": "/api/2.0/clean-rooms/{clean_room_name}/assets",
            "clean_rooms_assets_create": "/api/2.0/clean-rooms/{clean_room_name}/assets",
            "clean_rooms_assets_get": "/api/2.0/clean-rooms/{clean_room_name}/assets/{asset_name}",
            "clean_rooms_assets_update": "/api/2.0/clean-rooms/{clean_room_name}/assets/{asset_name}",
            "clean_rooms_assets_delete": "/api/2.0/clean-rooms/{clean_room_name}/assets/{asset_name}",
            "data_quality_monitors_list": "/api/2.0/data-quality-monitors/monitors",
            "data_quality_monitors_create": "/api/2.0/data-quality-monitors/monitors",
            "data_quality_monitors_get": "/api/2.0/data-quality-monitors/monitors/{monitor_id}",
            "data_quality_monitors_update": "/api/2.0/data-quality-monitors/monitors/{monitor_id}",
            "data_quality_monitors_delete": "/api/2.0/data-quality-monitors/monitors/{monitor_id}",
            "data_quality_monitor_refreshes_list": "/api/2.0/data-quality-monitors/monitors/{monitor_id}/refreshes",
            "data_quality_monitor_refreshes_create": "/api/2.0/data-quality-monitors/monitors/{monitor_id}/refreshes",
            "data_quality_monitor_refreshes_get": "/api/2.0/data-quality-monitors/monitors/{monitor_id}/refreshes/{refresh_id}",
            "data_quality_monitor_refreshes_update": "/api/2.0/data-quality-monitors/monitors/{monitor_id}/refreshes/{refresh_id}",
            "data_quality_monitor_refreshes_delete": "/api/2.0/data-quality-monitors/monitors/{monitor_id}/refreshes/{refresh_id}",
            "data_quality_monitor_refreshes_cancel": "/api/2.0/data-quality-monitors/monitors/{monitor_id}/refreshes/{refresh_id}/cancel",
            "instance_pools_list": "/api/2.0/instance-pools/list",
            "instance_pools_get": "/api/2.0/instance-pools/get",
            "instance_pools_create": "/api/2.0/instance-pools/create",
            "instance_pools_edit": "/api/2.0/instance-pools/edit",
            "instance_pools_delete": "/api/2.0/instance-pools/delete",
            "instance_pools_permissions_get": "/api/2.0/permissions/instance-pools/{instance_pool_id}",
            "instance_pools_permissions_set": "/api/2.0/permissions/instance-pools/{instance_pool_id}",
            "instance_pools_permissions_update": "/api/2.0/permissions/instance-pools/{instance_pool_id}",
            "instance_pools_permissions_levels": "/api/2.0/permissions/instance-pools/{instance_pool_id}/permissionLevels",
            "cluster_policies_list": "/api/2.0/policies/clusters/list",
            "cluster_policies_get": "/api/2.0/policies/clusters/get",
            "cluster_policies_create": "/api/2.0/policies/clusters/create",
            "cluster_policies_edit": "/api/2.0/policies/clusters/edit",
            "cluster_policies_delete": "/api/2.0/policies/clusters/delete",
            "dbfs_list": "/api/2.0/dbfs/list",
            "dbfs_get_status": "/api/2.0/dbfs/get-status",
            "dbfs_read": "/api/2.0/dbfs/read",
            "dbfs_delete": "/api/2.0/dbfs/delete",
            "dbfs_mkdirs": "/api/2.0/dbfs/mkdirs",
            "files_directories_list": "/api/2.0/files/directories",
            "files_directories_create": "/api/2.0/files/directories",
            "files_directories_delete": "/api/2.0/files/directories",
            "files_directories_metadata_get": "/api/2.0/files/directories/metadata",
            "files_download": "/api/2.0/files/files",
            "files_upload": "/api/2.0/files/files",
            "files_delete": "/api/2.0/files/files",
            "files_metadata_get": "/api/2.0/files/files/metadata",
            "instance_profiles_list": "/api/2.0/instance-profiles/list",
            "instance_profiles_add": "/api/2.0/instance-profiles/add",
            "instance_profiles_edit": "/api/2.0/instance-profiles/edit",
            "instance_profiles_remove": "/api/2.0/instance-profiles/remove",
            "libraries_all_cluster_statuses": "/api/2.0/libraries/all-cluster-statuses",
            "libraries_cluster_status": "/api/2.0/libraries/cluster-status",
            "libraries_install": "/api/2.0/libraries/install",
            "libraries_uninstall": "/api/2.0/libraries/uninstall",
            "ip_access_lists_list": "/api/2.0/ip-access-lists",
            "ip_access_lists_create": "/api/2.0/ip-access-lists",
            "ip_access_lists_get": "/api/2.0/ip-access-lists/{list_id}",
            "ip_access_lists_replace": "/api/2.0/ip-access-lists/{list_id}",
            "ip_access_lists_update": "/api/2.0/ip-access-lists/{list_id}",
            "ip_access_lists_delete": "/api/2.0/ip-access-lists/{list_id}",
            "notification_destinations_list": "/api/2.0/notification-destinations",
            "notification_destinations_create": "/api/2.0/notification-destinations",
            "notification_destinations_get": "/api/2.0/notification-destinations/{destination_id}",
            "notification_destinations_update": "/api/2.0/notification-destinations/{destination_id}",
            "notification_destinations_delete": "/api/2.0/notification-destinations/{destination_id}",
            "permissions_pipelines_get": "/api/2.0/permissions/pipelines/{pipeline_id}",
            "permissions_pipelines_set": "/api/2.0/permissions/pipelines/{pipeline_id}",
            "permissions_pipelines_update": "/api/2.0/permissions/pipelines/{pipeline_id}",
            "permissions_pipelines_permission_levels": "/api/2.0/permissions/pipelines/{pipeline_id}/permissionLevels",
            "pipelines_list": "/api/2.0/pipelines",
            "pipelines_create": "/api/2.0/pipelines",
            "pipelines_get": "/api/2.0/pipelines/{pipeline_id}",
            "pipelines_edit": "/api/2.0/pipelines/{pipeline_id}",
            "pipelines_delete": "/api/2.0/pipelines/{pipeline_id}",
            "pipelines_start": "/api/2.0/pipelines/{pipeline_id}/updates",
            "pipelines_stop": "/api/2.0/pipelines/{pipeline_id}/stop",
            "pipelines_events_list": "/api/2.0/pipelines/{pipeline_id}/events",
            "pipelines_updates_list": "/api/2.0/pipelines/{pipeline_id}/updates",
            "pipelines_updates_get": "/api/2.0/pipelines/{pipeline_id}/updates/{update_id}",
            "query_history_list": "/api/2.0/sql/history/queries",
            "permissions_serving_endpoints_get": "/api/2.0/permissions/serving-endpoints/{endpoint_name}",
            "permissions_serving_endpoints_set": "/api/2.0/permissions/serving-endpoints/{endpoint_name}",
            "permissions_serving_endpoints_update": "/api/2.0/permissions/serving-endpoints/{endpoint_name}",
            "permissions_serving_endpoints_permission_levels": "/api/2.0/permissions/serving-endpoints/{endpoint_name}/permissionLevels",
            "serving_endpoints_list": "/api/2.0/serving-endpoints",
            "serving_endpoints_create": "/api/2.0/serving-endpoints",
            "serving_endpoints_get": "/api/2.0/serving-endpoints/{endpoint_name}",
            "serving_endpoints_update_config": "/api/2.0/serving-endpoints/{endpoint_name}/config",
            "serving_endpoints_delete": "/api/2.0/serving-endpoints/{endpoint_name}",
            "serving_endpoints_query": "/api/2.0/serving-endpoints/{endpoint_name}/invocations",
            "marketplace_listings_list": "/api/2.0/marketplace-consumer/listings",
            "marketplace_listings_get": "/api/2.0/marketplace-consumer/listings/{listing_id}",
            "marketplace_listings_search": "/api/2.0/marketplace-consumer/listings/search",
            "marketplace_installations_list": "/api/2.0/marketplace-consumer/installations",
            "marketplace_installations_create": "/api/2.0/marketplace-consumer/installations",
            "marketplace_installations_get": "/api/2.0/marketplace-consumer/installations/{installation_id}",
            "marketplace_installations_delete": "/api/2.0/marketplace-consumer/installations/{installation_id}",
            "marketplace_provider_listings_list": "/api/2.0/marketplace-provider/listings",
            "marketplace_provider_listings_create": "/api/2.0/marketplace-provider/listings",
            "marketplace_provider_listings_get": "/api/2.0/marketplace-provider/listings/{listing_id}",
            "marketplace_provider_listings_update": "/api/2.0/marketplace-provider/listings/{listing_id}",
            "marketplace_provider_listings_delete": "/api/2.0/marketplace-provider/listings/{listing_id}",
            "marketplace_provider_providers_list": "/api/2.0/marketplace-provider/providers",
            "marketplace_provider_providers_create": "/api/2.0/marketplace-provider/providers",
            "marketplace_provider_providers_get": "/api/2.0/marketplace-provider/providers/{provider_id}",
            "marketplace_provider_providers_update": "/api/2.0/marketplace-provider/providers/{provider_id}",
            "marketplace_provider_providers_delete": "/api/2.0/marketplace-provider/providers/{provider_id}",
            "marketplace_provider_files_list": "/api/2.0/marketplace-provider/files",
            "marketplace_provider_files_create": "/api/2.0/marketplace-provider/files",
            "marketplace_provider_files_get": "/api/2.0/marketplace-provider/files/{file_id}",
            "marketplace_provider_files_update": "/api/2.0/marketplace-provider/files/{file_id}",
            "marketplace_provider_files_delete": "/api/2.0/marketplace-provider/files/{file_id}",
            "marketplace_provider_exchanges_list": "/api/2.0/marketplace-provider/exchanges",
            "marketplace_provider_exchanges_create": "/api/2.0/marketplace-provider/exchanges",
            "marketplace_provider_exchanges_get": "/api/2.0/marketplace-provider/exchanges/{exchange_id}",
            "marketplace_provider_exchanges_update": "/api/2.0/marketplace-provider/exchanges/{exchange_id}",
            "marketplace_provider_exchanges_delete": "/api/2.0/marketplace-provider/exchanges/{exchange_id}",
            "marketplace_provider_exchange_filters_list": "/api/2.0/marketplace-provider/exchange-filters",
            "marketplace_provider_exchange_filters_create": "/api/2.0/marketplace-provider/exchange-filters",
            "marketplace_provider_exchange_filters_get": "/api/2.0/marketplace-provider/exchange-filters/{filter_id}",
            "marketplace_provider_exchange_filters_update": "/api/2.0/marketplace-provider/exchange-filters/{filter_id}",
            "marketplace_provider_exchange_filters_delete": "/api/2.0/marketplace-provider/exchange-filters/{filter_id}",
            "marketplace_provider_personalization_requests_list": "/api/2.0/marketplace-provider/personalization-requests",
            "marketplace_provider_personalization_requests_get": "/api/2.0/marketplace-provider/personalization-requests/{request_id}",
            "marketplace_provider_personalization_requests_update": "/api/2.0/marketplace-provider/personalization-requests/{request_id}",
            "marketplace_provider_personalization_requests_delete": "/api/2.0/marketplace-provider/personalization-requests/{request_id}",
            "marketplace_consumer_personalization_requests_list": "/api/2.0/marketplace-consumer/personalization-requests",
            "marketplace_consumer_personalization_requests_create": "/api/2.0/marketplace-consumer/personalization-requests",
            "marketplace_consumer_personalization_requests_get": "/api/2.0/marketplace-consumer/personalization-requests/{request_id}",
            "marketplace_consumer_personalization_requests_update": "/api/2.0/marketplace-consumer/personalization-requests/{request_id}",
            "marketplace_consumer_personalization_requests_delete": "/api/2.0/marketplace-consumer/personalization-requests/{request_id}",
            "marketplace_consumer_providers_list": "/api/2.0/marketplace-consumer/providers",
            "marketplace_consumer_providers_get": "/api/2.0/marketplace-consumer/providers/{provider_id}",
            "marketplace_consumer_providers_batch_get": "/api/2.0/marketplace-consumer/providers/batch-get",
            "marketplace_consumer_fulfillments_list": "/api/2.0/marketplace-consumer/fulfillments",
            "marketplace_consumer_fulfillments_get": "/api/2.0/marketplace-consumer/fulfillments/{fulfillment_id}",
            "marketplace_provider_analytics_dashboard_get": "/api/2.0/marketplace-provider/providers/{provider_id}/analytics-dashboard",
            "marketplace_provider_analytics_dashboard_create": "/api/2.0/marketplace-provider/providers/{provider_id}/analytics-dashboard",
            "marketplace_provider_analytics_dashboard_update": "/api/2.0/marketplace-provider/providers/{provider_id}/analytics-dashboard",
            "marketplace_provider_analytics_dashboard_latest": "/api/2.0/marketplace-provider/providers/{provider_id}/analytics-dashboard/latest",
            "marketplace_provider_analytics_dashboard_delete": "/api/2.0/marketplace-provider/providers/{provider_id}/analytics-dashboard",
            "genie_spaces_list": "/api/2.0/genie/spaces",
            "genie_spaces_create": "/api/2.0/genie/spaces",
            "genie_spaces_get": "/api/2.0/genie/spaces/{space_id}",
            "genie_spaces_update": "/api/2.0/genie/spaces/{space_id}",
            "genie_spaces_delete": "/api/2.0/genie/spaces/{space_id}",
            "global_init_scripts_list": "/api/2.0/global-init-scripts",
            "global_init_scripts_create": "/api/2.0/global-init-scripts",
            "global_init_scripts_get": "/api/2.0/global-init-scripts/{script_id}",
            "global_init_scripts_update": "/api/2.0/global-init-scripts/{script_id}",
            "global_init_scripts_delete": "/api/2.0/global-init-scripts/{script_id}",
            "settings_v2_list_keys": "/api/2.0/settings-v2",
            "settings_v2_get": "/api/2.0/settings-v2/{setting_key}",
            "settings_v2_update": "/api/2.0/settings-v2/{setting_key}",
            "workspace_conf_get": "/api/2.0/workspace-conf",
            "workspace_conf_set": "/api/2.0/workspace-conf",
            "workspace_list": "/api/2.0/workspace/list",
            "workspace_mkdirs": "/api/2.0/workspace/mkdirs",
            "workspace_get_status": "/api/2.0/workspace/get-status",
            "workspace_export": "/api/2.0/workspace/export",
            "workspace_import": "/api/2.0/workspace/import",
            "workspace_delete": "/api/2.0/workspace/delete",
            "tag_policies_list": "/api/2.0/tags/policies",
            "tag_policies_create": "/api/2.0/tags/policies",
            "tag_policies_get": "/api/2.0/tags/policies/{policy_id}",
            "tag_policies_update": "/api/2.0/tags/policies/{policy_id}",
            "tag_policies_delete": "/api/2.0/tags/policies/{policy_id}",
            "tag_assignments_list": "/api/2.0/tags/assignments/{entity_type}/{entity_id}",
            "tag_assignments_create": "/api/2.0/tags/assignments/{entity_type}/{entity_id}",
            "tag_assignments_get": "/api/2.0/tags/assignments/{entity_type}/{entity_id}/{assignment_id}",
            "tag_assignments_update": "/api/2.0/tags/assignments/{entity_type}/{entity_id}/{assignment_id}",
            "tag_assignments_delete": "/api/2.0/tags/assignments/{entity_type}/{entity_id}/{assignment_id}",
            "quality_monitors_list": "/api/2.0/quality-monitor-v2/monitors",
            "quality_monitors_create": "/api/2.0/quality-monitor-v2/monitors",
            "quality_monitors_get": "/api/2.0/quality-monitor-v2/monitors/{monitor_id}",
            "quality_monitors_update": "/api/2.0/quality-monitor-v2/monitors/{monitor_id}",
            "quality_monitors_delete": "/api/2.0/quality-monitor-v2/monitors/{monitor_id}",
            "postgres_projects_list": "/api/2.0/postgres/projects",
            "postgres_projects_create": "/api/2.0/postgres/projects",
            "postgres_projects_get": "/api/2.0/postgres/projects/{project_id}",
            "postgres_projects_update": "/api/2.0/postgres/projects/{project_id}",
            "postgres_projects_delete": "/api/2.0/postgres/projects/{project_id}",
            "postgres_branches_list": "/api/2.0/postgres/projects/{project_id}/branches",
            "postgres_branches_create": "/api/2.0/postgres/projects/{project_id}/branches",
            "postgres_branches_get": "/api/2.0/postgres/projects/{project_id}/branches/{branch_id}",
            "postgres_branches_delete": "/api/2.0/postgres/projects/{project_id}/branches/{branch_id}",
            "permissions_jobs_get": "/api/2.0/permissions/jobs/{job_id}",
            "permissions_jobs_put": "/api/2.0/permissions/jobs/{job_id}",
            "permissions_jobs_patch": "/api/2.0/permissions/jobs/{job_id}",
            "permissions_jobs_permission_levels": "/api/2.0/permissions/jobs/{job_id}/permissionLevels",
            "permissions_clusters_get": "/api/2.0/permissions/clusters/{cluster_id}",
            "permissions_clusters_patch": "/api/2.0/permissions/clusters/{cluster_id}",
            "permissions_clusters_permission_levels": "/api/2.0/permissions/clusters/{cluster_id}/permissionLevels",
            "permissions_repos_get": "/api/2.0/permissions/repos/{repo_id}",
            "permissions_repos_patch": "/api/2.0/permissions/repos/{repo_id}",
            "permissions_repos_permission_levels": "/api/2.0/permissions/repos/{repo_id}/permissionLevels",
            "permissions_object_get": "/api/2.0/permissions/{object_type}/{object_id}",
            "permissions_object_set": "/api/2.0/permissions/{object_type}/{object_id}",
            "permissions_object_patch": "/api/2.0/permissions/{object_type}/{object_id}",
            "permissions_object_permission_levels": "/api/2.0/permissions/{object_type}/{object_id}/permissionLevels",
            "permissions_recipients_get": "/api/2.0/permissions/recipients/{name}",
            "permissions_recipients_set": "/api/2.0/permissions/recipients/{name}",
            "permissions_recipients_patch": "/api/2.0/permissions/recipients/{name}",
            "permissions_recipients_permission_levels": "/api/2.0/permissions/recipients/{name}/permissionLevels",
            "permissions_providers_get": "/api/2.0/permissions/providers/{name}",
            "permissions_providers_set": "/api/2.0/permissions/providers/{name}",
            "permissions_providers_patch": "/api/2.0/permissions/providers/{name}",
            "permissions_providers_permission_levels": "/api/2.0/permissions/providers/{name}/permissionLevels",
            "permissions_shares_get": "/api/2.0/permissions/shares/{name}",
            "permissions_shares_set": "/api/2.0/permissions/shares/{name}",
            "permissions_shares_patch": "/api/2.0/permissions/shares/{name}",
            "permissions_shares_permission_levels": "/api/2.0/permissions/shares/{name}/permissionLevels",
            "scim_current_user_get": "/api/2.0/preview/scim/v2/Me",
            "scim_groups_list": "/api/2.0/preview/scim/v2/Groups",
            "scim_groups_create": "/api/2.0/preview/scim/v2/Groups",
            "scim_groups_get": "/api/2.0/preview/scim/v2/Groups/{group_id}",
            "scim_groups_replace": "/api/2.0/preview/scim/v2/Groups/{group_id}",
            "scim_groups_delete": "/api/2.0/preview/scim/v2/Groups/{group_id}",
            "scim_groups_patch": "/api/2.0/preview/scim/v2/Groups/{group_id}",
            "scim_service_principals_list": "/api/2.0/preview/scim/v2/ServicePrincipals",
            "scim_service_principals_create": "/api/2.0/preview/scim/v2/ServicePrincipals",
            "scim_service_principals_get": "/api/2.0/preview/scim/v2/ServicePrincipals/{service_principal_id}",
            "scim_service_principals_replace": "/api/2.0/preview/scim/v2/ServicePrincipals/{service_principal_id}",
            "scim_service_principals_delete": "/api/2.0/preview/scim/v2/ServicePrincipals/{service_principal_id}",
            "scim_service_principals_patch": "/api/2.0/preview/scim/v2/ServicePrincipals/{service_principal_id}",
            "permissions_passwords_get": "/api/2.0/permissions/passwords/{user_id}",
            "permissions_passwords_set": "/api/2.0/permissions/passwords/{user_id}",
            "permissions_passwords_patch": "/api/2.0/permissions/passwords/{user_id}",
            "permissions_passwords_permission_levels": "/api/2.0/permissions/passwords/{user_id}/permissionLevels",
            "scim_users_list": "/api/2.0/preview/scim/v2/Users",
            "scim_users_create": "/api/2.0/preview/scim/v2/Users",
            "scim_users_get": "/api/2.0/preview/scim/v2/Users/{user_id}",
            "scim_users_replace": "/api/2.0/preview/scim/v2/Users/{user_id}",
            "scim_users_delete": "/api/2.0/preview/scim/v2/Users/{user_id}",
            "scim_users_patch": "/api/2.0/preview/scim/v2/Users/{user_id}",
            "vector_search_endpoints_list": "/api/2.0/vector-search/endpoints",
            "vector_search_endpoints_create": "/api/2.0/vector-search/endpoints",
            "vector_search_endpoints_get": "/api/2.0/vector-search/endpoints/{endpoint_name}",
            "vector_search_endpoints_update": "/api/2.0/vector-search/endpoints/{endpoint_name}",
            "vector_search_endpoints_delete": "/api/2.0/vector-search/endpoints/{endpoint_name}",
            "vector_search_indexes_list": "/api/2.0/vector-search/endpoints/{endpoint_name}/indexes",
            "vector_search_indexes_create": "/api/2.0/vector-search/endpoints/{endpoint_name}/indexes",
            "vector_search_indexes_get": "/api/2.0/vector-search/endpoints/{endpoint_name}/indexes/{index_name}",
            "vector_search_indexes_delete": "/api/2.0/vector-search/endpoints/{endpoint_name}/indexes/{index_name}",
            "vector_search_indexes_query": "/api/2.0/vector-search/endpoints/{endpoint_name}/indexes/{index_name}/query",
        },
        "2.1": {
            "jobs_create": "/api/2.1/jobs/create",
            "jobs_delete": "/api/2.1/jobs/delete",
            "jobs_get": "/api/2.1/jobs/get",
            "jobs_list": "/api/2.1/jobs/list",
            "jobs_reset": "/api/2.1/jobs/reset",
            "jobs_runs_cancel": "/api/2.1/jobs/runs/cancel",
            "jobs_runs_cancel_all": "/api/2.1/jobs/runs/cancel-all",
            "jobs_runs_delete": "/api/2.1/jobs/runs/delete",
            "jobs_runs_export": "/api/2.1/jobs/runs/export",
            "jobs_runs_get": "/api/2.1/jobs/runs/get",
            "jobs_runs_get_output": "/api/2.1/jobs/runs/get-output",
            "jobs_runs_list": "/api/2.1/jobs/runs/list",
            "jobs_runs_repair": "/api/2.1/jobs/runs/repair",
            "jobs_runs_submit": "/api/2.1/jobs/runs/submit",
            "jobs_run_now": "/api/2.1/jobs/run-now",
            "unity_catalog_catalogs_list": "/api/2.1/unity-catalog/catalogs",
            "unity_catalog_schemas_list": "/api/2.1/unity-catalog/schemas",
            "unity_catalog_catalogs_get": "/api/2.1/unity-catalog/catalogs/{catalog_name}",
            "unity_catalog_schemas_get": "/api/2.1/unity-catalog/schemas/{full_name}",
            "unity_catalog_connections_list": "/api/2.1/unity-catalog/connections",
            "unity_catalog_connections_create": "/api/2.1/unity-catalog/connections",
            "unity_catalog_connections_get": "/api/2.1/unity-catalog/connections/{name}",
            "unity_catalog_connections_update": "/api/2.1/unity-catalog/connections/{name}",
            "unity_catalog_connections_delete": "/api/2.1/unity-catalog/connections/{name}",
            "unity_catalog_external_locations_list": "/api/2.1/unity-catalog/external-locations",
            "unity_catalog_external_locations_create": "/api/2.1/unity-catalog/external-locations",
            "unity_catalog_external_locations_get": "/api/2.1/unity-catalog/external-locations/{name}",
            "unity_catalog_external_locations_update": "/api/2.1/unity-catalog/external-locations/{name}",
            "unity_catalog_external_locations_delete": "/api/2.1/unity-catalog/external-locations/{name}",
            "sharing_providers_list": "/api/2.1/unity-catalog/providers",
            "sharing_providers_create": "/api/2.1/unity-catalog/providers",
            "sharing_providers_get": "/api/2.1/unity-catalog/providers/{name}",
            "sharing_providers_update": "/api/2.1/unity-catalog/providers/{name}",
            "sharing_providers_delete": "/api/2.1/unity-catalog/providers/{name}",
            "sharing_providers_shares_list": "/api/2.1/unity-catalog/providers/{name}/shares",
            "sharing_providers_shares_create": "/api/2.1/unity-catalog/providers/{name}/shares",
            "sharing_providers_shares_get": "/api/2.1/unity-catalog/providers/{name}/shares/{share_name}",
            "sharing_providers_shares_update": "/api/2.1/unity-catalog/providers/{name}/shares/{share_name}",
            "sharing_providers_shares_delete": "/api/2.1/unity-catalog/providers/{name}/shares/{share_name}",
            "sharing_recipients_list": "/api/2.1/unity-catalog/recipients",
            "sharing_recipients_create": "/api/2.1/unity-catalog/recipients",
            "sharing_recipients_get": "/api/2.1/unity-catalog/recipients/{name}",
            "sharing_recipients_update": "/api/2.1/unity-catalog/recipients/{name}",
            "sharing_recipients_delete": "/api/2.1/unity-catalog/recipients/{name}",
            "sharing_recipients_rotate_token": "/api/2.1/unity-catalog/recipients/{name}/rotate-token",
            "sharing_recipients_shares_list": "/api/2.1/unity-catalog/recipients/{name}/shares",
            "sharing_recipients_shares_create": "/api/2.1/unity-catalog/recipients/{name}/shares",
            "sharing_recipients_shares_get": "/api/2.1/unity-catalog/recipients/{name}/shares/{share_name}",
            "sharing_recipients_shares_update": "/api/2.1/unity-catalog/recipients/{name}/shares/{share_name}",
            "sharing_recipients_shares_delete": "/api/2.1/unity-catalog/recipients/{name}/shares/{share_name}",
            "sharing_shares_list": "/api/2.1/unity-catalog/shares",
            "sharing_shares_create": "/api/2.1/unity-catalog/shares",
            "sharing_shares_get": "/api/2.1/unity-catalog/shares/{name}",
            "sharing_shares_providers_list": "/api/2.1/unity-catalog/shares/{name}/providers",
            "sharing_shares_providers_get": "/api/2.1/unity-catalog/shares/{name}/providers/{provider_name}",
            "sharing_shares_recipients_list": "/api/2.1/unity-catalog/shares/{name}/recipients",
            "sharing_shares_recipients_get": "/api/2.1/unity-catalog/shares/{name}/recipients/{recipient_name}",
            "sharing_shares_update": "/api/2.1/unity-catalog/shares/{name}",
            "sharing_shares_delete": "/api/2.1/unity-catalog/shares/{name}",
        },
        "preview": {},
    },
    "account": {
        "2.0": {
            "workspaces_create": "/api/2.0/accounts/workspaces",
            "workspaces_delete": "/api/2.0/accounts/workspaces/{workspace_id}",
            "workspaces_get": "/api/2.0/accounts/workspaces/{workspace_id}",
            "workspaces_list": "/api/2.0/accounts/workspaces",
            "workspaces_update": "/api/2.0/accounts/workspaces/{workspace_id}",
            "access_management_assignable_roles_get": "/api/2.0/iam/assignable-roles?resource={resource}",
            "access_management_rule_set_get": "/api/2.0/access-control/rule-sets/{name}",
            "access_management_rule_set_update": "/api/2.0/access-control/rule-sets/{name}",
            "credentials_list": "/api/2.0/accounts/credentials",
            "credentials_create": "/api/2.0/accounts/credentials",
            "credentials_delete": "/api/2.0/accounts/credentials/{credentials_id}",
            "storage_configurations_list": "/api/2.0/accounts/storage-configurations",
            "storage_configurations_create": "/api/2.0/accounts/storage-configurations",
            "storage_configurations_delete": "/api/2.0/accounts/storage-configurations/{storage_configuration_id}",
            "networks_list": "/api/2.0/accounts/networks",
            "networks_create": "/api/2.0/accounts/networks",
            "networks_delete": "/api/2.0/accounts/networks/{network_id}",
            "private_access_settings_list": "/api/2.0/accounts/private-access-settings",
            "private_access_settings_create": "/api/2.0/accounts/private-access-settings",
            "private_access_settings_delete": "/api/2.0/accounts/private-access-settings/{private_access_settings_id}",
            "vpc_endpoints_list": "/api/2.0/accounts/vpc-endpoints",
            "vpc_endpoints_create": "/api/2.0/accounts/vpc-endpoints",
            "vpc_endpoints_delete": "/api/2.0/accounts/vpc-endpoints/{vpc_endpoint_id}",
            "customer_managed_keys_list": "/api/2.0/accounts/customer-managed-keys",
            "customer_managed_keys_create": "/api/2.0/accounts/customer-managed-keys",
            "customer_managed_keys_delete": "/api/2.0/accounts/customer-managed-keys/{customer_managed_key_id}",
            "users_list": "/api/2.0/accounts/scim/v2/Users",
            "users_get": "/api/2.0/accounts/scim/v2/Users/{user_id}",
            "users_create": "/api/2.0/accounts/scim/v2/Users",
            "users_patch": "/api/2.0/accounts/scim/v2/Users/{user_id}",
            "users_delete": "/api/2.0/accounts/scim/v2/Users/{user_id}",
            "groups_list": "/api/2.0/accounts/scim/v2/Groups",
            "groups_get": "/api/2.0/accounts/scim/v2/Groups/{group_id}",
            "groups_create": "/api/2.0/accounts/scim/v2/Groups",
            "groups_patch": "/api/2.0/accounts/scim/v2/Groups/{group_id}",
            "groups_delete": "/api/2.0/accounts/scim/v2/Groups/{group_id}",
            "budget_policies_list": "/api/2.0/accounts/budget-policies",
            "budget_policies_get": "/api/2.0/accounts/budget-policies/{budget_policy_id}",
            "budget_policies_create": "/api/2.0/accounts/budget-policies",
            "budget_policies_update": "/api/2.0/accounts/budget-policies/{budget_policy_id}",
            "budget_policies_delete": "/api/2.0/accounts/budget-policies/{budget_policy_id}",
            "log_delivery_list": "/api/2.0/accounts/log-delivery",
            "log_delivery_get": "/api/2.0/accounts/log-delivery/{log_delivery_configuration_id}",
            "log_delivery_create": "/api/2.0/accounts/log-delivery",
            "log_delivery_patch": "/api/2.0/accounts/log-delivery/{log_delivery_configuration_id}",
            "log_delivery_delete": "/api/2.0/accounts/log-delivery/{log_delivery_configuration_id}",
            "identity_external_user_resolve": "/api/2.0/iam/v2/external-users/{external_id}",
            "identity_external_service_principal_resolve": "/api/2.0/iam/v2/external-service-principals/{external_id}",
            "identity_external_group_resolve": "/api/2.0/iam/v2/external-groups/{external_id}",
            "identity_workspace_access_get": "/api/2.0/iam/v2/workspace-access/{principal_id}",
        },
        "preview": {},
    },
}
